@@ -32,14 +32,14 @@ auction_template=r"""\begin{quote}
 """
 
 board_template=r"""\begin{quote}
-	\crdima{$ul}{%
-		\begin{minipage}[t]{\br}$ll\end{minipage}}%
-	{$north}%
-	{$west}%
-	{$east}%
-	{$south}%
-    {%
-		\begin{minipage}[t]{\br}$ur\end{minipage}}
+	\crdima
+    {\begin{minipage}[t]{\br}$ul\end{minipage}}
+    {\begin{minipage}[t]{\br}$ll\end{minipage}}
+    {$north}
+    {$west}
+    {$east}
+    {$south}
+    {\begin{minipage}[t]{\br}$ur\end{minipage}}
 \end{quote}
 """
 
@@ -154,7 +154,7 @@ def pbn_latex_deal(pbn, cards="NESW", ll="", ul="", ur=""):
                 all["south"] = ""
 
     if ul == "":
-        all["ul"] = latex_info(tags["Dealer"] + "/" + tags["Vulnerable"])
+        all["ul"] = latex_info("Dealer: " + tags["Dealer"] + "\\\\" + "Vul: " + tags["Vulnerable"])
     else:
         all["ul"] = latex_info(ul)
     all["ll"] = latex_info(ll, bottom=True)
